[−][src]Enum html_types::node::Node
Describes all potential shapes of a html element Note that there are only three kinds, text nodes, comment nodes, and element nodes but an element node can be void, or have children
Variants
Text(Text)Comment(Comment)Implementations
impl<'a> Node<'a>[src]
pub fn comment(text: &str) -> Self[src]
Creates a comment as a Node from the supplied string
pub fn text(text: &str) -> Self[src]
Creates a text element as a node